@@ -3,7 +3,8 @@ library(mdbr)
 
 test_that("tables can be read as data frames", {
   skip_on_cran()
-  dat <- read_mdb(mdb_example(), "Flights", stdout = tempfile())
+  skip_if_not(has_mdb_tools())
+  dat <- read_mdb(mdb_example(), "Flights", col_types = TRUE)
   expect_length(dat, 19)
   expect_s3_class(dat, "tbl")
   expect_s3_class(dat$time_hour, "POSIXt")
@@ -13,7 +14,8 @@ test_that("tables can be read as data frames", {
 
 test_that("tables can be read in memory", {
   skip_on_cran()
-  dat <- read_mdb(mdb_example(), "Flights", stdout = TRUE)
+  skip_if_not(has_mdb_tools())
+  dat <- read_mdb(mdb_example(), "Flights", col_types = TRUE)
   expect_length(dat, 19)
   expect_s3_class(dat, "tbl")
   expect_s3_class(dat$time_hour, "POSIXt")
@@ -23,10 +25,12 @@ test_that("tables can be read in memory", {
 
 test_that("reading errors without table name", {
   skip_on_cran()
+  skip_if_not(has_mdb_tools())
   expect_error(read_mdb(mdb_example()))
 })
 
 test_that("reading error when console stdout", {
   skip_on_cran()
+  skip_if_not(has_mdb_tools())
   expect_error(read_mdb(mdb_example(), "Flights", stdout = ""))
 })
